package othello.model;

import othello.observation.* ;

/** Interface for the game model
 * <p>Title: Othello</p>
 * <p>Description: </p>
 * <p>Copyright: Copyright (c) 2003</p>
 * <p>Company: Memorial University</p>
 * @author Theodore S. Norvell
 * @version 1.0
 */

public interface GameModelInterface extends GameConstants {
    /** Add a java.util.Observer.
     *  Observers will be notified after each mutator call
     */
    void addObserver( ConcurrentObserver o) ;
    /** Place a piece at a given position 
     *  Precondition: bw in {BLACK, WHITE}
     *  square(row, col) == EMPTY
     *  Postcondition square(row,col)==bw and all else unchanged
     */
    void layPiece( int row, int col, int bw) ;
    /** Flip the piece at a given position.
     *  square(row, col) in {BLACK,WHITE}
     *  Postcondition square(row,col)==the other colour and all else unchanged
     */
    void flipPiece( int row, int col ) ;
    /** Report the colour of a piece.
     *  Result will be in { BLACK, EMPTY, WHITE }
     */
    int getPieceAt( int row, int col ) ;
    
    static final int BLACK = -1 ;
    static final int EMPTY = 0 ;
    static final int WHITE = +1 ;
    
    static final int ROWS = 10 ;
    static final int COLS = 10 ;
}